@@ -1,4 +1,7 @@
 test_that("plotting future income", {
+  
+  skip_on_cran()
+  skip_on_ci()
 
   older_member <- HouseholdMember$new(
     name       = "older",  
