@@ -1,5 +1,8 @@
 test_that("plotting optimal portfolio", {
   
+  skip_on_cran()
+  skip_on_ci()
+  
   older_member <- HouseholdMember$new(
     name       = "older",  
     birth_date = "1980-02-15"
@@ -7,7 +10,7 @@ test_that("plotting optimal portfolio", {
   older_member$mode       <- 80
   older_member$dispersion <- 10
 
-household <- Household$new()
+  household <- Household$new()
   household$add_member(older_member)  
   household$risk_tolerance <- 0.1
   
